<?xml version='1.0'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
  xmlns="http://www.w3.org/TR/xhtml1/transitional" xmlns:fo="http://www.w3.org/1999/XSL/Format"
  xmlns:d="http://docbook.org/ns/docbook" exclude-result-prefixes="#default">

  <!-- Die Volkswagen Vorlage -->
  
  <xsl:import href="../xsl/fo/docbook.xsl"/>
  
  <!-- ab hier alle Spezialisierungen  -->
  
  <xsl:import href="titlepage.volkswagen.xsl"/>
  <xsl:import href="properties.xsl"/>
  <xsl:import href="attributes.xsl"/>
  <xsl:import href="table.xsl" />
  
  <xsl:template match="*[@role='small']">
    <fo:inline xsl:use-attribute-sets="text.font.small"><xsl:call-template name="inline.charseq" /></fo:inline>
  </xsl:template>
  
  <xsl:template match="d:para[@role='center']">
    <xsl:variable name="keep.together">
      <xsl:call-template name="pi.dbfo_keep-together"/>
    </xsl:variable>
    <fo:block xsl:use-attribute-sets="normal.para.spacing" text-align="center">
      <xsl:if test="$keep.together != ''">
        <xsl:attribute name="keep-together.within-column">
          <xsl:value-of select="$keep.together"/>
        </xsl:attribute>
      </xsl:if>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
    </fo:block>
  </xsl:template>

  <xsl:template name="header.content">
    <xsl:param name="pageclass" select="''"/>
    <xsl:param name="sequence" select="''"/>
    <xsl:param name="position" select="''"/>
    <xsl:param name="gentext-key" select="''"/>

    <fo:block>
      <!-- pageclass can be front, body, back -->
      <!-- sequence can be odd, even, first, blank -->
      <!-- position can be left, center, right -->
      <xsl:choose>
        <xsl:when test="$pageclass = 'titlepage'">
          <!-- nop; no footer on title pages -->
        </xsl:when>

        <xsl:when
          test="$double.sided != 0 and (( $sequence = 'even'
                      and $position='left' ) or (($sequence = 'odd' or $sequence = 'first')
                      and $position='right'))">
          <fo:page-number/>
        </xsl:when>

        <xsl:when test="$double.sided != 0 and  $sequence = 'odd' and $position='right'">
          <fo:inline>
            <fo:page-number/>
          </fo:inline>
        </xsl:when>

        <xsl:when test="$double.sided != 0 and  $sequence = 'even' and $position='left'">
          <fo:inline>
            <fo:page-number/>
          </fo:inline>
        </xsl:when>

        <xsl:when test="$double.sided != 0 and  $sequence = 'odd' and $position='center'">
          <fo:block text-align="left" color="grey">
            <xsl:text>Standards of IT Architecture &#x007c; </xsl:text>
            <xsl:apply-templates select="." mode="title.markup"/>
          </fo:block>
          <fo:block text-align="center" color="#FF6600">
            <xsl:text>- Internal Use By Volkswagen Group Employees Only -</xsl:text>
          </fo:block>
        </xsl:when>

        <xsl:when test="$double.sided != 0 and  $sequence = 'even' and $position='center'">
          <fo:block text-align="right" color="grey">
            <xsl:text>Standards of IT Architecture &#x007c; </xsl:text>
            <xsl:apply-templates select="." mode="title.markup"/>
          </fo:block>
          <fo:block text-align="center" color="#FF6600">
            <xsl:text>- Internal Use By Volkswagen Group Employees Only -</xsl:text>
          </fo:block>
        </xsl:when>

        <xsl:when test="$sequence='blank'">
          <xsl:choose>
            <xsl:when test="$double.sided != 0 and $position = 'left'">
              <fo:page-number/>
            </xsl:when>
            <xsl:when test="$double.sided = 0 and $position = 'center'">
              <fo:page-number/>
            </xsl:when>
            <xsl:otherwise>
              <!-- nop -->
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        <xsl:otherwise>
          <!-- nop -->
        </xsl:otherwise>
      </xsl:choose>
    </fo:block>
  </xsl:template>

  <xsl:template name="footer.content">
    <xsl:param name="pageclass" select="''"/>
    <xsl:param name="sequence" select="''"/>
    <xsl:param name="position" select="''"/>
    <xsl:param name="gentext-key" select="''"/>

    <fo:block>
      <xsl:variable name="copyYear">
        <xsl:choose>
          <xsl:when test="//d:copyright/d:year">
            <xsl:value-of select="//d:copyright/d:year"/>
          </xsl:when>
        </xsl:choose>
      </xsl:variable>

      <xsl:variable name="copyHolder">
        <xsl:choose>
          <xsl:when test="//d:copyright/d:holder">
            <xsl:value-of select="//d:copyright/d:holder"/>
          </xsl:when>
        </xsl:choose>
      </xsl:variable>

      <xsl:choose>
        <xsl:when test="$pageclass = 'titlepage'">
          <!--  nop; no footer on title pages -->
        </xsl:when>
        <xsl:when
          test="$double.sided != 0 and (( $sequence = 'even'
          and $position='left' ) or ($sequence = 'odd'
          and $position='right'))">
          <fo:inline color="grey">
            <xsl:text>© </xsl:text>
            <xsl:value-of select="$copyYear"/>
            <xsl:text> / </xsl:text>
            <xsl:value-of select="$copyHolder"/>
          </fo:inline>
        </xsl:when>

        <xsl:otherwise> </xsl:otherwise>

      </xsl:choose>
    </fo:block>
  </xsl:template>


  
  <!--
Referenzen auf  
 -->
  <xsl:template match="section" mode="xref-to">
    <xsl:param name="referrer"/>
    <xsl:param name="xrefstyle"/>

    <xsl:value-of select="count(./ancestor::chapter/preceding-sibling::chapter) + 1"/>
    <xsl:text>-</xsl:text>
    <xsl:value-of select="count(./preceding-sibling::section) + 1"/>
  </xsl:template>

  <xsl:template match="d:table|d:informaltable">
    <xsl:if test="d:tgroup/d:tbody/d:tr
      |d:tgroup/d:thead/d:tr
      |d:tgroup/d:tfoot/d:tr">
      <xsl:message terminate="yes">
        <xsl:text>Broken table: tr descendent of CALS Table.</xsl:text>
        <xsl:text>The text in the first tr is:&#10;</xsl:text>
        <xsl:value-of select="(d:tgroup//d:tr)[1]"/>
      </xsl:message>
    </xsl:if>
    <xsl:if test="not(d:tgroup) and .//d:row">
      <xsl:message terminate="yes">
        <xsl:text>Broken table: row descendent of HTML table.</xsl:text>
        <xsl:text>The text in the first row is:&#10;</xsl:text>
        <xsl:value-of select=".//d:row[1]"/>
      </xsl:message>
    </xsl:if>

    <!-- Contains fo:table, not title or footnotes -->
    <xsl:variable name="table.content">
      <xsl:call-template name="make.table.content"/>
    </xsl:variable>

    <!-- Optional layout table template for extensions -->
    <xsl:variable name="table.layout">
      <xsl:call-template name="table.layout">
        <xsl:with-param name="table.content" select="$table.content"/>
      </xsl:call-template>
    </xsl:variable>

    <!-- fo:block contains title, layout table, and footnotes  -->
    <xsl:variable name="table.block">
      <xsl:call-template name="table.block">
        <xsl:with-param name="table.layout" select="$table.layout"/>
      </xsl:call-template>
    </xsl:variable>

    <!-- pgwide or orient container -->
    <xsl:variable name="table.container">
      <xsl:call-template name="table.container">
        <xsl:with-param name="table.block" select="$table.block"/>
      </xsl:call-template>
    </xsl:variable>

    <!-- float or not -->
    <xsl:variable name="floatstyle">
      <xsl:call-template name="floatstyle"/>
    </xsl:variable>

    <xsl:choose>
      <xsl:when test="$floatstyle != ''">
        <xsl:call-template name="floater">
          <xsl:with-param name="position" select="$floatstyle"/>
          <xsl:with-param name="content" select="$table.container"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:copy-of select="$table.container"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Removed the table title from the output -->
  <xsl:template name="table.block">
    <xsl:param name="table.layout" select="NOTANODE"/>

    <xsl:variable name="id">
      <xsl:call-template name="object.id"/>
    </xsl:variable>

    <xsl:variable name="param.placement"
      select="substring-after(normalize-space(
      $formal.title.placement), concat(local-name(.), ' '))"/>

    <xsl:variable name="placement">
      <xsl:choose>
        <xsl:when test="contains($param.placement, ' ')">
          <xsl:value-of select="substring-before($param.placement, ' ')"/>
        </xsl:when>
        <xsl:when test="$param.placement = ''">before</xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$param.placement"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:variable name="keep.together">
      <xsl:call-template name="pi.dbfo_keep-together"/>
    </xsl:variable>

    <xsl:choose>
      <xsl:when test="self::d:table">
        <fo:block id="{$id}" xsl:use-attribute-sets="table.properties">
          <xsl:if test="$keep.together != ''">
            <xsl:attribute name="keep-together.within-column">
              <xsl:value-of select="$keep.together"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:if test="$placement = 'before'">
            <xsl:call-template name="formal.object.heading">
              <xsl:with-param name="placement" select="$placement"/>
            </xsl:call-template>
          </xsl:if>
          <xsl:copy-of select="$table.layout"/>
          <xsl:call-template name="table.footnote.block"/>
          <xsl:if test="$placement != 'before'"> </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <fo:block id="{$id}" xsl:use-attribute-sets="informaltable.properties">
          <xsl:copy-of select="$table.layout"/>
          <xsl:call-template name="table.footnote.block"/>
        </fo:block>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <!-- customize this template to add row properties -->
  <xsl:template name="table.row.properties">

    <xsl:variable name="row-height">
      <xsl:if test="processing-instruction('dbfo')">
        <xsl:call-template name="pi.dbfo_row-height"/>
      </xsl:if>
    </xsl:variable>

    <xsl:if test="$row-height != ''">
      <xsl:attribute name="block-progression-dimension">
        <xsl:value-of select="$row-height"/>
      </xsl:attribute>
    </xsl:if>

    <!-- Setze die bgcolor fuer eine Zeile der Tabelle -->
    <xsl:variable name="bgcolor">
      <xsl:choose>
        <xsl:when test="ancestor::d:thead or ancestor::d:tfoot">
          <!-- bgcolor fuer den Header der Tabelle -->
          <xsl:if test="@role='WithVersion'">#C0C0C0</xsl:if>
          <xsl:if test="@role='LimitedUse'">#0000FF</xsl:if>
          <xsl:if test="@role='Rollout'">#339966</xsl:if>
          <xsl:if test="@role='Freeze'">#FFFF99</xsl:if>
          <xsl:if test="@role='Replace'">#FF9999</xsl:if>
        </xsl:when>
        <xsl:otherwise>
          <!-- bgcolor fuer die einzelnen Zeilen -->
          <xsl:if test="@role='LimitedUse'">#9AB7D7</xsl:if>
          <xsl:if test="@role='Rollout'">#CCFFCC</xsl:if>
          <xsl:if test="@role='Freeze'">#FFFF99</xsl:if>
          <xsl:if test="@role='Replace'">#FF9999</xsl:if>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:if test="$bgcolor != ''">
      <xsl:attribute name="background-color">
        <xsl:value-of select="$bgcolor"/>
      </xsl:attribute>
    </xsl:if>

    <!-- Keep header row with next row -->
    <xsl:if test="ancestor::d:thead">
      <xsl:attribute name="keep-with-next.within-column">always</xsl:attribute>
    </xsl:if>

  </xsl:template>

  <!-- Ausgabe des Headers einer Tabelle -->
  <xsl:template name="table.cell.block.properties">
    <!-- highlight this entry? -->
    <xsl:if test="ancestor::d:thead or ancestor::d:tfoot">
      <xsl:attribute name="font-weight">bold</xsl:attribute>
      <!-- Setze die FArbe fuer die Ausgabe -->
      <xsl:attribute name="color">
        <xsl:if test="ancestor::*[@role='Rollout']">#FFFFFF</xsl:if>
        <xsl:if test="ancestor::*[@role='LimitedUse']">#FFFFFF</xsl:if>
      </xsl:attribute>
    </xsl:if>
  </xsl:template>

</xsl:stylesheet>
