<?xml version="1.0"?>
<xsl:stylesheet 
     xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
     xmlns:fo="http://www.w3.org/1999/XSL/Format"
     xmlns:d="http://docbook.org/ns/docbook"
     exclude-result-prefixes="d"
     version="1.0">

  <xsl:variable name="white">#FFFFFF</xsl:variable>
  <xsl:variable name="black">#000000</xsl:variable>

  <xsl:variable name="darkgreen">#008000</xsl:variable>
  <xsl:variable name="green">#00FF00</xsl:variable>
  <xsl:variable name="lightgreen">#80FF80</xsl:variable>

  <xsl:variable name="darkblue">#000080</xsl:variable>
  <xsl:variable name="blue">#0000FF</xsl:variable>
  <xsl:variable name="lightblue">#8080FF</xsl:variable>

  <xsl:variable name="darkred">#800000</xsl:variable>
  <xsl:variable name="red">#FF0000</xsl:variable>
  <xsl:variable name="lightred">#FF8080</xsl:variable>

  <xsl:variable name="darkyellow">#808000</xsl:variable>
  <xsl:variable name="yellow">#FFFF00</xsl:variable>
  <xsl:variable name="lightyellow">#FFFF80</xsl:variable>

  <xsl:variable name="darkgrey">#808080</xsl:variable>
  <xsl:variable name="lightgrey">#A0A0A0</xsl:variable>

  <!-- Summmary tables have different headers -->

  <xsl:template match="d:thead">
    <xsl:message>Entered d:thead</xsl:message>

    <!-- Set the color of specific header rows -->
    <xsl:choose>
      <xsl:when test="@role='summary'">
        <xsl:call-template name="bosthead">
          <xsl:with-param name="boscolor"><xsl:value-of select="$darkgreen"/></xsl:with-param>
          <xsl:with-param name="bostcolor"><xsl:value-of select="$white"/></xsl:with-param>
        </xsl:call-template>
      </xsl:when>
      <xsl:when test="@role='limitedUseSummary'">
        <xsl:call-template name="bosthead">
          <xsl:with-param name="boscolor"><xsl:value-of select="$darkblue"/></xsl:with-param>
          <xsl:with-param name="bostcolor"><xsl:value-of select="$white"/></xsl:with-param>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="bosthead">
          <xsl:with-param name="boscolor"><xsl:value-of select="$lightgrey"/></xsl:with-param>
          <xsl:with-param name="bostcolor"><xsl:value-of select="$black"/></xsl:with-param>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="bosthead">
    <xsl:param name="boscolor"/>
    <xsl:param name="bostcolor"/>
    <xsl:variable name="tgroup" select="parent::*"/>
    <fo:table-header start-indent="0pt" end-indent="0pt" background-color="{$boscolor}" color="{$bostcolor}">
      <xsl:apply-templates select="d:row[1]">
        <xsl:with-param name="spans">
          <xsl:call-template name="blank.spans">
            <xsl:with-param name="cols" select="../@cols"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:apply-templates>
    </fo:table-header>
  </xsl:template>

  <!-- Different quadranbts have different colors -->
  <xsl:template match="d:row">
    <xsl:param name="spans"/>

    <xsl:choose>
      <xsl:when test="contains($spans, '0')">
          <xsl:choose>
            <xsl:when test="@role='roll-out'">
              <xsl:call-template name="bos-row">
                <xsl:with-param name="spans" select="$spans"/>
                <xsl:with-param name="boscolor"><xsl:value-of select="$green"/></xsl:with-param>
              </xsl:call-template>
            </xsl:when>
            <xsl:when test="@role='phase-out'">
              <xsl:call-template name="bos-row">
                <xsl:with-param name="spans" select="$spans"/>
                <xsl:with-param name="boscolor"><xsl:value-of select="$lightred"/></xsl:with-param>
              </xsl:call-template>
            </xsl:when>
            <xsl:when test="@role='tolerate'">
              <xsl:call-template name="bos-row">
                <xsl:with-param name="spans" select="$spans"/>
                <xsl:with-param name="boscolor"><xsl:value-of select="$darkgrey"/></xsl:with-param>
              </xsl:call-template>
            </xsl:when>
            <xsl:when test="@role='freeze'">
              <xsl:call-template name="bos-row">
                <xsl:with-param name="spans" select="$spans"/>
                <xsl:with-param name="boscolor"><xsl:value-of select="$lightyellow"/></xsl:with-param>
              </xsl:call-template>
            </xsl:when>
            <xsl:when test="@role='limitedUse'">
              <xsl:call-template name="bos-row">
                <xsl:with-param name="spans" select="$spans"/>
                <xsl:with-param name="boscolor"><xsl:value-of select="$lightblue"/></xsl:with-param>
              </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
              <xsl:call-template name="normal-row">
                <xsl:with-param name="spans" select="$spans"/>
              </xsl:call-template>
            </xsl:otherwise>
          </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:if test="normalize-space(.//text()) != ''">
          <xsl:message>Warning: overlapped row contains content!</xsl:message>
        </xsl:if>

        <fo:table-row>
          <xsl:comment> This row intentionally left blank </xsl:comment>
          <fo:table-cell><fo:block/></fo:table-cell>
        </fo:table-row>

        <xsl:apply-templates select="following-sibling::d:row[1]">
          <xsl:with-param name="spans">
            <xsl:call-template name="consume-row">
              <xsl:with-param name="spans" select="$spans"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:apply-templates>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Rows in a BoS table -->
  <xsl:template name="bos-row">
    <xsl:param name="spans"/>
    <xsl:param name="boscolor"/>

    <fo:table-row background-color="{$boscolor}">
      <xsl:call-template name="table.row.properties"/>
      <xsl:call-template name="anchor"/>

      <xsl:apply-templates select="(d:entry|d:entrytbl)[1]">
        <xsl:with-param name="spans" select="$spans"/>
      </xsl:apply-templates>
    </fo:table-row>

    <xsl:if test="following-sibling::d:row">
      <xsl:variable name="nextspans">
        <xsl:apply-templates select="(d:entry|d:entrytbl)[1]" mode="span">
          <xsl:with-param name="spans" select="$spans"/>
        </xsl:apply-templates>
      </xsl:variable>

      <xsl:apply-templates select="following-sibling::d:row[1]">
        <xsl:with-param name="spans" select="$nextspans"/>
      </xsl:apply-templates>
    </xsl:if>
  </xsl:template>
</xsl:stylesheet>
