package com.print;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.transform.ErrorListener;
import javax.xml.transform.OutputKeys;
import javax.xml.transform.Result;
import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.URIResolver;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.apache.fop.servlet.ServletContextURIResolver;
import org.w3c.dom.Document;

/**
 * Nimmt ein DocBook XML-File und generiert daraus FO aus den DocBook XSLTs.
 */
public final class DocBook2FOTransformer extends HttpServlet {

	private static final long serialVersionUID = -6853878455086575149L;

	private Transformer transformer = null;

	private DocumentBuilderFactory factory = null;

	@Override
	public void init(ServletConfig config) throws ServletException {

		super.init(config);

		factory = DocumentBuilderFactory.newInstance();
		factory.setXIncludeAware(true);
		factory.setNamespaceAware(true);

		ErrorListener errorListener = new TransformerErrorListener(config
				.getServletContext());

		// Get the stylesheet in the servlet engine document directory
		URIResolver xslSourceResolver = new ServletContextURIResolver(
				getServletContext());

		Source xslSource;
		try {
			xslSource = xslSourceResolver.resolve(
					"servlet-context:/BoSStylesheet/fo.xsl", null);
			/*
			 * Achtung! auch die TransformerFactory ist NICHT threadsafe! Wir
			 * brauchen jedesmal eine neue oder synchronisieren an der Stelle
			 * der Nutzung im Servlet.
			 * 
			 * Ein Transformer darf zwar wiederverwendet werden (eventuell
			 * vorher reset() rufen), jedoch nicht parallel (von konkurrierenden
			 * Threads), nur sequenziell. Diese Wiederverwendung kann aber sehr
			 * attraktiv sein, da das Parsen einer XSL-Hierarchie unter
			 * Umständen sehr aufwändig sein kann und eigentlich nur einmal zu
			 * erfolgen hat.
			 */
			TransformerFactory factory = TransformerFactory.newInstance();
			factory.setErrorListener(errorListener);
			factory.setURIResolver(xslSourceResolver);

			this.transformer = factory.newTransformer(xslSource);
			this.transformer.setURIResolver(xslSourceResolver);
			this.transformer.setErrorListener(errorListener);
			


		} catch (TransformerException e) {
			throw new ServletException(e);
		}
	}

	@Override
	protected void doGet(final HttpServletRequest req,
			final HttpServletResponse response) throws ServletException,
			IOException {

		// Set content type for HTML.
		response.setContentType("text/xml; charset=UTF-8");

		// Output goes to the response PrintWriter.
		final PrintWriter out = response.getWriter();

		try {

			/*
			 * Durchführen der Transformation.
			 * 
			 * Weil der Transformer nicht Threadsafe ist, muss hier
			 * synchronisiert werden. Für bessere Skalierbarkeit müssen
			 * Transformer Instanzen gepooled werden. Dazu nimmt man einen
			 * Resource Adapter oder einen Apache Instance Pool.
			 */
			synchronized (this) {
				// TODO muss das Dokument denn über eine DOM Source gehen?!
				// geht es nicht wie bei FO2PDF über
				//    Source src = new StreamSource(req.getParameter("fo"));
				// Nein, den xincludes werden nicht aufgelöst!
				// Lösung wird noch gesucht
				DocumentBuilder docBuilder = this.factory.newDocumentBuilder();

				
				Document doc = docBuilder.parse(req.getParameter("xml"));

				Source xmlSource = new DOMSource(doc);

				Result res = new StreamResult(out);
				/*
				 * Der Request muss das Encoding liefern, das wir dem Transformer
				 * mitteilen 
				 */
				if (req.getCharacterEncoding() != null) {
				    this.transformer.setOutputProperty(OutputKeys.ENCODING, req.getCharacterEncoding());
				}
				this.transformer.transform(xmlSource, res);
				this.transformer.clearParameters();
			}

		} catch (Exception e) {
			throw new ServletException(e);
		}
	}
}