package com.print;

import javax.servlet.ServletContext;
import javax.xml.transform.ErrorListener;
import javax.xml.transform.TransformerException;

/**
 * Minimaler {@link ErrorListener} zum Gebrauch mit einem Servlet.
 * 
 * In Abhängigkeit von der Serverkonfiguration können die
 * Ausgaben normalerweise im ServerLog eingesehen werden.
 * 
 * Der Lebenszyklus einer TransformerErrorListener-Instanz
 * sollten an der des Servlets gebunden werden, nur dann steht ein
 * intakter {@link ServletContext} zur Verfügung.
 * 
 * Wie auch immer die Implementierung ausfällt: sie muss
 * thread safe sein! Hier ist das gegeben, da außer dem
 * Zugriff auf den {@link ServletContext} (welcher Thread safe
 * ist) nichts weiter gemacht wird.
 */
public final class TransformerErrorListener implements ErrorListener {

	private final ServletContext context;
	
	public TransformerErrorListener(final ServletContext context) {
		this.context = context;
	}
	
	public void error(TransformerException e)
	throws TransformerException {
		this.context.log("error", e);
	}
	
	public void fatalError(TransformerException e)
	throws TransformerException {
		this.context.log("fatalError", e);
	}
	
	public void warning(TransformerException e)
	throws TransformerException {
		this.context.log("warning", e);
	}
}